@@ -11,7 +11,7 @@ require bytes;
 use Encode;
 use JSON::Any;
 
-our $VERSION = '0.01002';
+our $VERSION = '0.02';
 
 has certificate => (
     is       => 'rw',
@@ -59,11 +59,6 @@ has on_connect => (
 
 no Any::Moose;
 
-sub BUILD {
-    my ($self) = @_;
-    $self->_connect;
-}
-
 sub send {
     my $self = shift;
     my ($token, $payload) = @_;
@@ -87,10 +82,13 @@ sub _error_handler {
     $self->on_error(@_);
 }
 
-sub _connect {
+sub connect {
     my $self = shift;
 
-    undef $self->{handler};
+    if ($self->handler) {
+        warn 'Already connected!';
+        return;
+    }
 
     my $host = $self->sandbox
         ? 'gateway.sandbox.push.apple.com'
@@ -142,6 +140,7 @@ AnyEvent::APNS - Simple wrapper for Apple Push Notifications Service (APNS) prov
             });
         },
     );
+    $apns->connect;
     
     # disconnect and exit program as soon as possible after sending a message
     # otherwise $apns makes persistent connection with apns server
@@ -156,11 +155,16 @@ AnyEvent::APNS - Simple wrapper for Apple Push Notifications Service (APNS) prov
 
 This module helps you to create Apple Push Notifications Service (APNS) Provider.
 
+=head1 NOTE FOR 0.01x USERS
+
+From 0.02, this module does not connect in constructor.
+You should call connect method explicily to connect server.
+
 =head1 METHODS
 
 =head2 new
 
-Create APNS object and connect to apns service.
+Create APNS object.
 
     my $apns = AnyEvent::APNS->new(
         certificate => 'your apns certificate file',
@@ -202,6 +206,10 @@ Optional (Default: empty coderef)
 
 =back
 
+=head2 $apns->connect;
+
+Connect to apns server.
+
 =head2 $apns->send( $device_token, \%payload )
 
 Send apns messages with C<\%payload> to device speficied C<$device_token>.
